@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::5_0::Direct;
-$Search::Elasticsearch::Client::5_0::Direct::VERSION = '5.02';
+package Search::Elasticsearch::Client::6_0::Direct;
+$Search::Elasticsearch::Client::6_0::Direct::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
 use Search::Elasticsearch::Util qw(parse_params is_compat);
@@ -75,11 +75,11 @@ __PACKAGE__->_install_api('');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct - Thin client with full support for Elasticsearch 5.x APIs
+Search::Elasticsearch::Client::6_0::Direct - Thin client with full support for Elasticsearch 6.x APIs
 
 =head1 VERSION
 
-version 5.02
+version 6.00
 
 =head1 SYNOPSIS
 
@@ -87,7 +87,7 @@ Create a client:
 
     use Search::Elasticsearch;
     my $e = Search::Elasticsearch->new(
-        client => '5_0::Direct'
+        client => '6_0::Direct'
     );
 
 Index a doc:
@@ -168,11 +168,11 @@ Task management:
 
 =head1 DESCRIPTION
 
-The L<Search::Elasticsearch::Client::5_0::Direct> class provides the
-Elasticsearch 5.x compatible client returned by:
+The L<Search::Elasticsearch::Client::6_0::Direct> class provides the
+Elasticsearch 6.x compatible client returned by:
 
     $e = Search::Elasticsearch->new(
-        client => "5_0::Direct"  # default
+        client => "6_0::Direct"  # default
     );
 
 It is intended to be as close as possible to the native REST API that
@@ -187,16 +187,20 @@ and the L<cluster|/cluster()>.
 
 =head1 PREVIOUS VERSIONS OF ELASTICSEARCH
 
-This version of the client supports the Elasticsearch 5.0 branch,
+This version of the client supports the Elasticsearch 6.0 branch,
 which is not backwards compatible with earlier branches.
 
-If you need to talk to a version of Elasticsearch before 5.0.0, please
+If you need to talk to a version of Elasticsearch before 6.0.0, please
 install one of the following modules:
 
 =over
 
 =item *
 
+L<Search::Elasticsearch::Client::5_0>
+
+=item *
+
 L<Search::Elasticsearch::Client::2_0>
 
 =item *
@@ -240,11 +244,11 @@ as top level parameters:
 If you pass in a C<\%params> hash, then it will be included in the
 query string parameters without any error checking. The following:
 
-    $e->search( size => 10, params => { from => 5, size => 5 })
+    $e->search( size => 10, params => { from => 6, size => 6 })
 
 would result in this query string:
 
-    ?from=5&size=10
+    ?from=6&size=10
 
 =head2 Body parameter
 
@@ -261,6 +265,21 @@ UTF-8 bytes and passed as is:
 
     $e->indices->analyze( body => "The quick brown fox");
 
+=head2 Boolean parameters
+
+Elasticsearch 6.0.0 and above no longer accepts truthy and falsey values for booleans.  Instead,
+it will accept only a JSON C<true> or C<false>, or the string equivalents C<"true"> or C<"false">.
+
+In the Perl client, you can use the following values:
+
+=over
+
+=item * True: C<true>, C<\1>, or a L<JSON::PP::Boolean> object.
+
+=item * False: C<false>, C<\0>, or a L<JSON::PP::Boolean> object.
+
+=back
+
 =head2 Filter path parameter
 
 Any API which returns a JSON body accepts a C<filter_path> parameter
@@ -302,12 +321,12 @@ Multiple error codes can be specified with an array:
 =head2 C<bulk_helper_class>
 
 The class to use for the L</bulk_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::5_0::Bulk>.
+L<Search::Elasticsearch::Client::6_0::Bulk>.
 
 =head2 C<scroll_helper_class>
 
 The class to use for the L</scroll_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::5_0::Scroll>.
+L<Search::Elasticsearch::Client::6_0::Scroll>.
 
 =head1 GENERAL METHODS
 
@@ -329,7 +348,7 @@ response, otherwise it throws an error.
 
     $indices_client = $e->indices;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Indices> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Indices> object which can be used
 for managing indices, eg creating, deleting indices, managing mapping,
 index settings etc.
 
@@ -337,28 +356,28 @@ index settings etc.
 
     $ingest_client = $e->ingest;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Ingest> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Ingest> object which can be used
 for managing ingest pipelines.
 
 =head2 C<cluster()>
 
     $cluster_client = $e->cluster;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Cluster> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Cluster> object which can be used
 for managing the cluster, eg cluster-wide settings and cluster health.
 
 =head2 C<nodes()>
 
     $node_client = $e->nodes;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Nodes> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Nodes> object which can be used
 to retrieve node info and stats.
 
 =head2 C<snapshot()>
 
     $snapshot_client = $e->snapshot;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Snapshot> object which
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Snapshot> object which
 is used for managing backup repositories and creating and restoring
 snapshots.
 
@@ -366,14 +385,14 @@ snapshots.
 
     $tasks_client = $e->tasks;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Tasks> object which
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Tasks> object which
 is used for accessing the task management API.
 
 =head2 C<cat()>
 
     $cat_client = $e->cat;
 
-Returns a L<Search::Elasticsearch::Client::5_0::Direct::Cat> object which can be used
+Returns a L<Search::Elasticsearch::Client::6_0::Direct::Cat> object which can be used
 to retrieve simple to read text info for debugging and monitoring an
 Elasticsearch cluster.
 
@@ -587,7 +606,7 @@ C<index>, C<type> and C<id> if it exists. Updates can be performed either by:
         body => {
             script => {
                 inline => "ctx._source.counter += incr",
-                params => { incr => 5 }
+                params => { incr => 6 }
             }
         }
     );
@@ -600,7 +619,7 @@ C<index>, C<type> and C<id> if it exists. Updates can be performed either by:
             script => {
                 id     => $id,
                 lang   => 'painless',
-                params => { incr => 5 }
+                params => { incr => 6 }
             }
         }
     );
@@ -616,7 +635,7 @@ for more information.
             script => {
                 file   => 'counter',
                 lang   => 'painless',
-                params => { incr => 5 }
+                params => { incr => 6 }
             }
         }
     );
@@ -696,7 +715,7 @@ that need to be made, bulk requests greatly improve performance.
         body    => [ actions ]          # required
     );
 
-See L<Search::Elasticsearch::Client::5_0::Bulk> and L</bulk_helper()> for a helper module that makes
+See L<Search::Elasticsearch::Client::6_0::Bulk> and L</bulk_helper()> for a helper module that makes
 bulk indexing simpler to use.
 
 The C<bulk()> method can perform multiple L</index()>, L</create()>,
@@ -746,7 +765,7 @@ For instance:
             { title => 'Foo' },
 
             # delete action
-            { delete => { _id => 125 }},
+            { delete => { _id => 126 }},
 
             # update action
             { update => { _id => 126 }},
@@ -778,7 +797,7 @@ for more information.
     $bulk_helper = $e->bulk_helper( @args );
 
 Returns a new instance of the class specified in the L</bulk_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::5_0::Bulk>.
+which defaults to L<Search::Elasticsearch::Client::6_0::Bulk>.
 
 =head2 C<mget()>
 
@@ -929,11 +948,12 @@ Query string parameters:
     C<error_trace>,
     C<expand_wildcards>,
     C<explain>,
-    C<fielddata_fields>,
     C<from>,
     C<human>,
     C<ignore_unavailable>,
     C<lenient>,
+    C<max_concurrent_shard_requests>,
+    C<pre_filter_shard_size>,
     C<preference>,
     C<q>,
     C<request_cache>,
@@ -951,6 +971,7 @@ Query string parameters:
     C<terminate_after>,
     C<timeout>,
     C<track_scores>,
+    C<track_total_hits>,
     C<typed_keys>,
     C<version>
 
@@ -994,7 +1015,8 @@ Query string parameters:
     C<min_score>,
     C<preference>,
     C<q>,
-    C<routing>
+    C<routing>,
+    Cterminate_after>
 
 See the L<count docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-count.html>
 for more information.
@@ -1024,7 +1046,7 @@ within the C<body>) and parameters to use with the template, eg:
             params => {
                 my_field => 'foo',
                 my_value => 'bar',
-                my_size  => 5
+                my_size  => 6
             }
         }
     );
@@ -1067,7 +1089,7 @@ Renders the template, filling in the passed-in parameters and returns the result
             params => {
                 my_field => 'foo',
                 my_value => 'bar',
-                my_size  => 5
+                my_size  => 6
             }
         }
     );
@@ -1089,7 +1111,7 @@ C<scroll> parameter, the C<scroll()>
 method allows you to keep pulling more results until the results
 are exhausted.
 
-See L</scroll_helper()> and L<Search::Elasticsearch::Client::5_0::Scroll> for a helper utility
+See L</scroll_helper()> and L<Search::Elasticsearch::Client::6_0::Scroll> for a helper utility
 which makes managing scroll requests much easier.
 
 Query string parameters:
@@ -1118,7 +1140,7 @@ up resources on the server.
     $scroll_helper = $e->scroll_helper( @args );
 
 Returns a new instance of the class specified in the L</scroll_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::5_0::Scroll>.
+which defaults to L<Search::Elasticsearch::Client::6_0::Scroll>.
 
 =head2 C<msearch()>
 
@@ -1153,6 +1175,7 @@ Query string parameters:
     C<error_trace>,
     C<human>,
     C<max_concurrent_searches>,
+    C<pre_filter_shard_size>,
     C<search_type>,
     C<typed_keys>
 
@@ -1191,10 +1214,11 @@ request).  For instance:
 Query string parameters:
     C<error_trace>,
     C<human>,
+    C<max_concurrent_searches>,
     C<search_type>,
     C<typed_keys>
 
-See the L<msearch-template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/multi-search-template.html>
+See the L<msearch-template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-multi-search.html>
 for more information.
 
 =head2 C<explain()>
@@ -1242,17 +1266,14 @@ Query string parameters:
 See the L<explain docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-explain.html>
 for more information.
 
-=head2 C<field_stats()>
+=head2 C<field_caps()>
 
-    $response = $e->field_stats(
+    $response = $e->field_caps(
         index   => 'index'   | \@indices,   # optional
-        fields  => 'field'   | \@fields,    # optional
-        level   => 'cluster' | 'indices',   # optional
         body    => { filters }              # optional
     );
 
-The C<field-stats> API returns statistical properties of a field
-(such as min and max values) without executing a search.
+The C<field-caps> API returns field types and abilities, merged across indices.
 
 Query string parameters:
     C<allow_no_indices>,
@@ -1260,17 +1281,15 @@ Query string parameters:
     C<expand_wildcards>,
     C<fields>,
     C<human>,
-    C<ignore_unavailable>,
-    C<level>
+    C<ignore_unavailable>
 
-See the L<field-stats docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-field-stats.html>
+See the L<field-caps docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-field-caps.html>
 for more information.
 
 =head2 C<search_shards()>
 
     $response = $e->search_shards(
         index   => 'index' | \@indices,     # optional
-        type    => 'type'  | \@types,       # optional
     )
 
 The C<search_shards()> method returns information about which shards on
@@ -1432,170 +1451,6 @@ Query string parameters:
 See the L<reindex docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/docs-reindex.html>
 for more information.
 
-=head1 PERCOLATION METHODS
-
-=head2 C<percolate()>
-
-    $results = $e->percolate(
-        index   => 'my_index',      # required
-        type    => 'my_type',       # required
-
-        body    => { percolation }  # required
-    );
-
-Percolation is search inverted: instead of finding docs which match a
-particular query, it finds queries which match a particular document, eg
-for I<alert-me-when> functionality.
-
-The C<percolate()> method runs a percolation request to find the
-queries matching a particular document. In the C<body> you should pass the
-C<_source> field of the document under the C<doc> key:
-
-    $results = $e->percolate(
-        index   => 'my_index',
-        type    => 'my_type',
-        body    => {
-            doc => {
-                title => 'Elasticsearch rocks'
-            }
-        }
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<error_trace>,
-    C<expand_wildcards>,
-    C<human>,
-    C<ignore_unavailable>,
-    C<percolate_format>,
-    C<percolate_index>,
-    C<percolate_preference>,
-    C<percolate_routing>,
-    C<percolate_type>,
-    C<preference>,
-    C<routing>,
-    C<version>,
-    C<version_type>
-
-See the L<percolate docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html>
-for more information.
-
-=head2 C<count_percolate()>
-
-    $results = $e->count_percolate(
-        index   => 'my_index',      # required
-        type    => 'my_type',       # required
-
-        body    => { percolation }  # required
-    );
-
-The L</count_percolate()> request works just like the L</percolate()>
-request except that it returns a count of all matching queries, instead
-of the queries themselves.
-
-    $results = $e->count_percolate(
-        index   => 'my_index',
-        type    => 'my_type',
-        body    => {
-            doc => {
-                title => 'Elasticsearch rocks'
-            }
-        }
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<error_trace>,
-    C<expand_wildcards>,
-    C<human>,
-    C<ignore_unavailable>,
-    C<percolate_index>,
-    C<percolate_type>,
-    C<preference>,
-    C<routing>,
-    C<version>,
-    C<version_type>
-
-See the L<percolate docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html>
-for more information.
-
-=head2 C<mpercolate()>
-
-    $results = $e->mpercolate(
-        index   => 'my_index',               # required if type
-        type    => 'my_type',                # optional
-
-        body    => [ percolation requests ]  # required
-    );
-
-Multi-percolation allows multiple L</percolate()> requests to be run
-in a single request.
-
-    $results = $e->mpercolate(
-        index   => 'my_index',
-        type    => 'my_type',
-        body    => [
-            # first request
-            { percolate => {
-                index => 'twitter',
-                type  => 'tweet'
-            }},
-            { doc => {message => 'some_text' }},
-
-            # second request
-            { percolate => {
-                index => 'twitter',
-                type  => 'tweet',
-                id    => 1
-            }},
-            {},
-        ]
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<error_trace>,
-    C<expand_wildcards>,
-    C<human>,
-    C<ignore_unavailable>
-
-See the L<mpercolate docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-percolate.html>
-for more information.
-
-=head2 C<suggest()>
-
-    $results = $e->suggest(
-        index   => 'index' | \@indices,     # optional
-
-        body    => { suggest request }      # required
-    );
-
-The C<suggest()> method is used to run
-L<did-you-mean|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-suggesteres-phrase.html>
-or L<search-as-you-type|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-suggesters-completion.html>
-suggestion requests, which can also be run as part of a L</search()> request.
-
-    $results = $e->suggest(
-        index   => 'my_index',
-        body    => {
-            my_suggestions => {
-                phrase  => {
-                    text    => 'johnny walker',
-                    field   => 'title'
-                }
-            }
-        }
-    );
-
-Query string parameters:
-    C<allow_no_indices>,
-    C<error_trace>,
-    C<expand_wildcards>,
-    C<human>,
-    C<ignore_unavailable>,
-    C<preference>,
-    C<routing>
-
 =head1 INDEXED SCRIPT METHODS
 
 Elasticsearch allows you to store scripts in the cluster state
@@ -1604,18 +1459,18 @@ and reference them by id. The methods to manage indexed scripts are as follows:
 =head2 C<put_script()>
 
     $result  = $e->put_script(
-        lang => 'lang',     # required
-        id   => 'id',       # required
-        body => { script }  # required
+        id      => 'id',       # required
+        context => $context,   # optional
+        body    => { script }  # required
     );
 
 The C<put_script()> method is used to store a script in the cluster state. For instance:
 
     $result  = $e->put_scripts(
-        lang => 'painless',
         id   => 'hello_world',
         body => {
-          script => q(return "hello world");
+          lang   => 'painless',
+          source => q(return "hello world");
         }
     );
 
@@ -1628,7 +1483,6 @@ See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/refe
 =head2 C<get_script()>
 
     $script = $e->get_script(
-        lang => 'lang',     # required
         id   => 'id',       # required
     );
 
@@ -1643,7 +1497,6 @@ See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/refe
 =head2 C<delete_script()>
 
     $script = $e->delete_script(
-        lang => 'lang',     # required
         id   => 'id',       # required
     );
 
@@ -1651,73 +1504,12 @@ Delete the indexed script from the cluster state.
 
 Query string parameters:
     C<error_trace>,
-    C<human>
+    C<human>,
+    C<master_timeout>,
+    C<timeout>
 
 See the L<indexed scripts docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/modules-scripting.html#_indexed_scripts> for more.
 
-=head1 INDEXED SEARCH TEMPLATE METHODS
-
-Mustache templates can be used to create search requests.  These templates can
-be stored in the cluster state and retrieved by ID. The methods to
-manage indexed scripts are as follows:
-
-=head2 C<put_template()>
-
-    $result  = $e->put_template(
-        id   => 'id',                       # required
-        body => { template } || "template"  # required
-    );
-
-The C<put_template()> method is used to store a template in the cluster state.
-For instance:
-
-    $result  = $e->put_template(
-        id   => 'hello_world',
-        body => {
-          template => {
-            query => {
-              match => {
-                title => "hello world"
-              }
-            }
-          }
-      }
-    );
-
-Query string parameters:
-    C<error_trace>,
-    C<human>
-
-See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html#_pre_registered_template> for more.
-
-=head2 C<get_template()>
-
-    $script = $e->get_template(
-        id   => 'id',       # required
-    );
-
-Retrieve the indexed template from the cluster state.
-
-Query string parameters:
-    C<error_trace>,
-    C<human>
-
-See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html#_pre_registered_template> for more.
-
-=head2 C<delete_template()>
-
-    $script = $e->delete_template(
-        id   => 'id',       # required
-    );
-
-Delete the indexed template from the cluster state.
-
-Query string parameters:
-    C<error_trace>,
-    C<human>
-
-See the L<indexed search template docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/search-template.html#_pre_registered_template> for more.
-
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
@@ -1734,5 +1526,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Thin client with full support for Elasticsearch 5.x APIs
+# ABSTRACT: Thin client with full support for Elasticsearch 6.x APIs
 
