@@ -1,7 +1,7 @@
-package Search::Elasticsearch::Client::5_0::Direct::Cluster;
-$Search::Elasticsearch::Client::5_0::Direct::Cluster::VERSION = '5.02';
+package Search::Elasticsearch::Client::6_0::Direct::Cluster;
+$Search::Elasticsearch::Client::6_0::Direct::Cluster::VERSION = '6.00';
 use Moo;
-with 'Search::Elasticsearch::Client::5_0::Role::API';
+with 'Search::Elasticsearch::Client::6_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 __PACKAGE__->_install_api('cluster');
 
@@ -13,11 +13,11 @@ __PACKAGE__->_install_api('cluster');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::5_0::Direct::Cluster - A client for running cluster-level requests
+Search::Elasticsearch::Client::6_0::Direct::Cluster - A client for running cluster-level requests
 
 =head1 VERSION
 
-version 5.02
+version 6.00
 
 =head1 DESCRIPTION
 
@@ -102,7 +102,7 @@ For instance:
 
     $response = $e->cluster->put_settings(
         body => {
-            transient => { "discovery.zen.minimum_master_nodes" => 5 }
+            transient => { "discovery.zen.minimum_master_nodes" => 6 }
         }
     );
 
@@ -220,6 +220,19 @@ Query string parameters:
 See the L<reroute docs|http://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-reroute.html>
 for more information.
 
+=head2 C<remote_info()>
+
+    $response = $e->cluster->remote_info();
+
+The C<remote_info()> API retrieves all of the configured remote cluster information.
+
+Query string parameters:
+    C<error_trace>,
+    C<human>
+
+See the L<remote_info docs|https://www.elastic.co/guide/en/elasticsearch/reference/current/cluster-remote-info.html>
+for more information.
+
 =head1 AUTHOR
 
 Clinton Gormley <drtech@cpan.org>
